==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescription } from "./DataContextDescription";
/**
 * @hidden
 */
export let DataContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataContextDescriptionMetadata extends Base {
        static b(a) {
            if (DataContextDescriptionMetadata.a == null) {
                DataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataContextDescriptionMetadata.c(DataContextDescriptionMetadata.a);
            }
            if (a.j(DataContextDescriptionMetadata.a)) {
                return;
            }
            a.y(DataContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("ActualItemBrush", "Brush");
            a.item("Outline", "Brush");
            a.item("ItemLabelRef", "(w:ItemLabel,wf:ItemLabel)DataRef");
            a.item("ItemBrush", "Brush");
            a.item("Thickness", "Number:double");
            a.item("LegendLabelRef", "(w:LegendLabel,wf:LegendLabel)DataRef");
        }
        static d(a) {
            DataContextDescriptionMetadata.b(a);
            a.aa("DataContext", () => new DataContextDescription());
            a.z("DataContext", DataContextDescriptionMetadata.a);
        }
    }
    DataContextDescriptionMetadata.$t = /*@__PURE__*/ markType(DataContextDescriptionMetadata, 'DataContextDescriptionMetadata');
    DataContextDescriptionMetadata.a = null;
    return DataContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescription } from "./DataContextDescription";
/**
 * @hidden
 */
export let DataContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataContextDescriptionMetadata extends Base {
        static b(a) {
            if (DataContextDescriptionMetadata.a == null) {
                DataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataContextDescriptionMetadata.c(DataContextDescriptionMetadata.a);
            }
            if (a.k(DataContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(DataContextDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("ActualItemBrush", "Brush");
            a.item("Outline", "Brush");
            a.item("ItemLabelRef", "(w:ItemLabel,wf:ItemLabel)DataRef");
            a.item("ItemBrush", "Brush");
            a.item("Thickness", "Number:double");
            a.item("LegendLabelRef", "(w:LegendLabel,wf:LegendLabel)DataRef");
        }
        static d(a) {
            DataContextDescriptionMetadata.b(a);
            a.ac("DataContext", () => new DataContextDescription());
            a.ab("DataContext", DataContextDescriptionMetadata.a);
        }
    }
    DataContextDescriptionMetadata.$t = /*@__PURE__*/ markType(DataContextDescriptionMetadata, 'DataContextDescriptionMetadata');
    DataContextDescriptionMetadata.a = null;
    return DataContextDescriptionMetadata;
})();
